async fn enter_aprs_session(
radio: Radio<EitherTransport>,
config: AprsClientConfig,
tx: &UnboundedSender<Message>,
cmd_rx: &mut UnboundedReceiver<RadioCommand>,
) -> Result<Radio<EitherTransport>, EnterAprsError>Expand description
Enter APRS mode, run the event loop, and return the radio on clean exit.
Takes ownership of the Radio (consumed by AprsClient::start), runs the
APRS event loop, and returns the Radio after AprsClient::stop.