async fn enter_dstar_session(
radio: Radio<EitherTransport>,
config: DStarGatewayConfig,
tx: &UnboundedSender<Message>,
cmd_rx: &mut UnboundedReceiver<RadioCommand>,
) -> Result<Radio<EitherTransport>, EnterDStarError>Expand description
Enter D-STAR gateway mode, run the event loop, and return the radio on clean exit.
Takes ownership of the Radio (consumed by DStarGateway::start), runs the
D-STAR event loop, and returns the Radio after DStarGateway::stop.